==> sghi_core-0.2.5.tar.gz: lib/afya_moja_core/src/domain/core/entities/content/document.dart <==
import 'package:freezed_annotation/freezed_annotation.dart';
import 'package:sghi_core/afya_moja_core/src/constants.dart';

part 'document.freezed.dart';
part 'document.g.dart';

@Freezed(makeCollectionsUnmodifiable: false)
class Document with _$Document {
  factory Document({
    @JsonKey(name: 'ID') int? id,
    @JsonKey(name: 'Document') DocumentData? documentData,
  }) = _Document;

  factory Document.fromJson(Map<String, dynamic> json) =>
      _$DocumentFromJson(json);

  factory Document.initial() => Document(
        id: 0,
        documentData: DocumentData.initial(),
      );
}

@Freezed(makeCollectionsUnmodifiable: false)
class DocumentData with _$DocumentData {
  factory DocumentData({
    @JsonKey(name: 'ID') int? id,
    @JsonKey(name: 'title') String? title,
    @JsonKey(name: 'meta') DocumentMetaData? documentMetaData,
  }) = _DocumentData;

  factory DocumentData.fromJson(Map<String, dynamic> json) =>
      _$DocumentDataFromJson(json);

  factory DocumentData.initial() => DocumentData(
        id: 0,
        title: UNKNOWN,
        documentMetaData: DocumentMetaData.initial(),
      );
}

@Freezed(makeCollectionsUnmodifiable: false)
class DocumentMetaData with _$DocumentMetaData {
  factory DocumentMetaData({
    @JsonKey(name: 'documentDownloadUrl') String? documentDownloadUrl,
  }) = _DocumentMetaData;

  factory DocumentMetaData.fromJson(Map<String, dynamic> json) =>
      _$DocumentMetaDataFromJson(json);

  factory DocumentMetaData.initial() =>
      DocumentMetaData(documentDownloadUrl: UNKNOWN);
}

==> sghi_core-0.2.30.tar.gz: lib/afya_moja_core/src/domain/core/entities/content/document.dart <==
import 'package:freezed_annotation/freezed_annotation.dart';
import 'package:sghi_core/afya_moja_core/src/constants.dart';

part 'document.freezed.dart';
part 'document.g.dart';

@Freezed(makeCollectionsUnmodifiable: false)
class Document with _$Document {
  factory Document({
    @JsonKey(name: 'id') int? id,
    @JsonKey(name: 'document') DocumentData? documentData,
  }) = _Document;

  factory Document.fromJson(Map<String, dynamic> json) =>
      _$DocumentFromJson(json);

  factory Document.initial() => Document(
        id: 0,
        documentData: DocumentData.initial(),
      );
}

@Freezed(makeCollectionsUnmodifiable: false)
class DocumentData with _$DocumentData {
  factory DocumentData({
    @JsonKey(name: 'id') int? id,
    @JsonKey(name: 'title') String? title,
    @JsonKey(name: 'meta') DocumentMetaData? documentMetaData,
  }) = _DocumentData;

  factory DocumentData.fromJson(Map<String, dynamic> json) =>
      _$DocumentDataFromJson(json);

  factory DocumentData.initial() => DocumentData(
        id: 0,
        title: UNKNOWN,
        documentMetaData: DocumentMetaData.initial(),
      );
}

@Freezed(makeCollectionsUnmodifiable: false)
class DocumentMetaData with _$DocumentMetaData {
  factory DocumentMetaData({
    @JsonKey(name: 'documentDownloadUrl') String? documentDownloadUrl,
  }) = _DocumentMetaData;

  factory DocumentMetaData.fromJson(Map<String, dynamic> json) =>
      _$DocumentMetaDataFromJson(json);

  factory DocumentMetaData.initial() =>
      DocumentMetaData(documentDownloadUrl: UNKNOWN);
}
